@@ -29,7 +29,7 @@ class MainWindow(tkinter.Tk):
         self.beamSpot = True
         self.title("GBAR MCPy")
         self.geometry("900x600")
-        self.resizable(False,True)
+        self.resizable(True,True)
         self.canBeAnalysed = False
         self.canBeExported = False
         
@@ -63,7 +63,7 @@ class MainWindow(tkinter.Tk):
         self.savedAs.grid(row=2,column=1)
         """
         
-        add = static_addr = path.join(static_addr,"GBAR_logo.png")
+        add = path.join(static_addr,"GBAR_logo.png")
         img = Image.open(add)
         img = img.resize((100, 100), Image.ANTIALIAS)
         img = ImageTk.PhotoImage(img)
@@ -85,7 +85,7 @@ class MainWindow(tkinter.Tk):
         self.frame2.pack(side='right')
         
         ### MCP parameters
-        add = static_addr = path.join(static_addr,"BGT_in.mcp")
+        add = path.join(static_addr,"BGT_in.mcp")
         self.mcp_param = import_config(add)
        
 
